==> colourettu-1.0.0.zip: colourettu-1.0.0/setup.py <==
import os
import codecs
import re
from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    # intentionally *not* adding an encoding option to open
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


long_description = read('readme.rst') + '\n' + read('changes.rst')


setup(
    name='colourettu',
    version=find_version('colourettu', '__init__.py'),
    url='http://github.com/minchinweb/colourettu',
    license='MIT License',
    author='William Minchin',
    install_requires=['',
                      ],
    author_email='w_minchin@hotmail.com',
    description='Colour related functions',
    long_description=long_description,
    packages=['colourettu'],
    package_data={'': ['readme.rst', 'changes.rst', 'LICENSE']},
    include_package_data=True,
    platforms='any',
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Development Status :: 5 - Production/Stable',
        'Natural Language :: English',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Multimedia :: Graphics',
        ],
)

==> colourettu-1.1.0.zip: colourettu-1.1.0/setup.py <==
import os
import codecs
import re
from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    # intentionally *not* adding an encoding option to open
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


long_description = read('readme.rst')


setup(
    name='colourettu',
    version=find_version('colourettu', '__init__.py'),
    url='http://github.com/minchinweb/colourettu',
    license='MIT License',
    author='William Minchin',
    install_requires=['Pillow',
                      ],
    author_email='w_minchin@hotmail.com',
    description='Colour related functions',
    long_description=long_description,
    packages=['colourettu'],
    package_data={'': ['readme.rst', 'LICENSE']},
    include_package_data=True,
    platforms='any',
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Development Status :: 5 - Production/Stable',
        'Natural Language :: English',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Multimedia :: Graphics',
        ],
)
